import numpy as np
import matplotlib.pyplot as plt


def plot(df, norm_max=True, streamlit=False):
    df = df.copy()
    # if type(norm_max) == list:
    df /= norm_max
    # if norm_max:
    #     df /= df.max()

    angles = np.linspace(0, 2 * np.pi, len(df.columns), endpoint=False)
    angles = np.concatenate((angles, [angles[0]]))  # close the plot

    fig = plt.figure()
    ax = fig.add_subplot(111, polar=True)

    for i in df.index:
        stats = df.loc[i, :].values
        stats = np.concatenate((stats, [stats[0]]))  # close the plot
        ax.plot(angles, stats, 'o-', linewidth=2, label=i)
        ax.fill(angles, stats, alpha=0.25)

    ax.legend(loc='upper left', bbox_to_anchor=(1, 1))

    columns = list(df.columns) + list(df.columns[:1])
    # print((angles * 180 / np.pi).shape, len(columns))
    ax.set_thetagrids(angles * 180 / np.pi, columns)
    ax.grid(True)
    if streamlit:
        return fig, ax
    return ax



from setuptools import setup, find_packages

# Read dependencies from requirements.txt
with open("requirements.txt") as f:
    install_requires = f.read().splitlines()

setup(
    name="radarchart-py",
    version="0.1.2",
    author="Sabir Ribas",
    author_email="sabirribas+pypi@gmail.com",
    description="RadarChart: A Python library for customizable radar charts (spider plots)",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/sabirribas/radarchart",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    license="MIT",
    packages=find_packages(),
    python_requires=">=3.6",
    install_requires=install_requires,  # Load dependencies from file
    entry_points={
        'console_scripts': [
            'radarchart=radarchart:main',  # Example CLI entry point
        ],
    },
    include_package_data=True,
)
